@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2006 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -53,7 +53,7 @@
 #endif /* !defined(_) */
 
 
-#define WEECHAT_COPYRIGHT_DATE   "(C) 2003-2017"
+#define WEECHAT_COPYRIGHT_DATE   "(C) 2003-2018"
 #define WEECHAT_WEBSITE          "https://weechat.org/"
 #define WEECHAT_WEBSITE_DOWNLOAD "https://weechat.org/download"
 
@@ -96,7 +96,10 @@
 /* name of environment variable with an extra lib dir */
 #define WEECHAT_EXTRA_LIBDIR "WEECHAT_EXTRA_LIBDIR"
 
+struct t_weelist;
+
 /* global variables and functions */
+extern int weechat_headless;
 extern int weechat_debug_core;
 extern char *weechat_argv0;
 extern int weechat_upgrading;
@@ -104,17 +107,18 @@ extern int weechat_first_start;
 extern time_t weechat_first_start_time;
 extern struct timeval weechat_current_start_timeval;
 extern int weechat_upgrade_count;
-extern int weechat_quit;
+extern volatile sig_atomic_t weechat_quit;
 extern volatile sig_atomic_t weechat_quit_signal;
 extern char *weechat_home;
 extern char *weechat_local_charset;
 extern int weechat_plugin_no_dlclose;
 extern int weechat_no_gnutls;
 extern int weechat_no_gcrypt;
-extern char *weechat_startup_commands;
+extern struct t_weelist *weechat_startup_commands;
 
 extern void weechat_term_check ();
 extern void weechat_shutdown (int return_code, int crash);
+extern void weechat_init_gettext ();
 extern void weechat_init (int argc, char *argv[], void (*gui_init_cb)());
 extern void weechat_end (void (*gui_end_cb)(int clean_exit));
 
